/*********************************************************************
    LAkernel_all_vs_all.c (version 0.2)                                          
                                                                    
    Compute the local alignment kernel between all pairs of proteins
    in a FASTA format file.

    Reference:
    H. Saigo, J.-P. Vert, T. Akutsu and N. Ueda, "Protein homology 
    detection using string alignment kernels", Bioinformatics, 
    vol.20, p.1682-1689, 2004.
                                                                    
                                                                    
    Copyright 2003 Jean-Philippe Vert                                 

    This file is part of LAkernel.

    LAkernel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Foobar is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Foobar; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 *********************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "LAkernel.h"
#include "seqio.h"

int main(int argc, char *argv[])
{
  SEQFILE *sfp;
  SEQINFO *sip;
  char *seq1 , *seq2;
  int len, processed=0, cont=1 , i;
  
  if (argc != 2) {
    fprintf(stderr, "pHMM_1_vs_all : compute the pair HMM logprobability between all pairs of proteins in a database.\n\nUsage: pHMM_all_vs_all database.file\n");
    exit(1);
  }

  while (cont) {
    
    /* open the database file and search the first query sequenced not processed yet */
    if ((sfp = seqfopen2(argv[1])) == NULL) {
      fprintf(stderr,"Unable to open %s\n",argv[2]);
      exit(1);
    }
    i=0;
    while (((seq1 = seqfgetseq(sfp, &len, 1)) != NULL) && (i<processed)) {
      i++;
      free(seq1);
    }
    if (seq1 == NULL)
      cont = 0;
    else {
      processed++;
      /* seq1 contains the query protein. Retrieve and print its name */
      sip = seqfinfo(sfp,1);
      printf("%s",sip->description);
      free(sip);
      seqfclose(sfp);

      /* next open the database file */
      if ((sfp = seqfopen2(argv[1])) == NULL) {
	fprintf(stderr,"Unable to open %s\n",argv[2]);
	exit(1);
      }

      /* Read sequences one by one in the database */
      while ((seq2 = seqfgetseq(sfp, &len, 1)) != NULL) {
	
	/* Compute the pair HMM log-probability and print it */
	printf("\t%.2f",LAkernel(seq1,seq2));
	
	free(seq2);
      }

      seqfclose(sfp);
      printf("\n");

      free(seq1);
    }
  }
  return 0;
}
